==> monodevelop-2.2.1.tar.bz2: monodevelop-2.2.1/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui/ToolbarComboBox.cs <==
//
// ConfigurationComboBox.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Core;
using MonoDevelop.Projects;
using MonoDevelop.Core.Gui;
using MonoDevelop.Components.Commands;

namespace MonoDevelop.Ide.Gui
{
	internal class ToolbarComboBox: CustomItem
	{
		Gtk.Alignment align;
		Gtk.ComboBox combo;
		Gtk.CellRendererText ctx;
		
		public ToolbarComboBox () 
		{
			align = new Gtk.Alignment (0.5f, 0.5f, 1.0f, 0f);
			Add (align);
			
			align.LeftPadding = 3;
			align.RightPadding = 3;
			
			combo = new Gtk.ComboBox ();
			combo.Model = new Gtk.ListStore (typeof(string));
			ctx = new Gtk.CellRendererText ();
			combo.PackStart (ctx, true);
			combo.AddAttribute (ctx, "text", 0);
			
			align.Add (combo);
			ShowAll ();
		}
		
		protected Gtk.ComboBox Combo {
			get { return combo; }
		}
		
		public override void SetToolbarStyle (Gtk.Toolbar toolbar)
		{
			if (Style != null) {
				if (toolbar.IconSize == Gtk.IconSize.Menu || toolbar.IconSize == Gtk.IconSize.SmallToolbar) {
					Pango.FontDescription fd = Style.FontDescription.Copy ();
					fd.Size = (int) (fd.Size * Pango.Scale.Small);
					ctx.FontDesc = fd;
				} else {
					ctx.FontDesc = Style.FontDescription;
				}
			}
		}
	}
}

==> monodevelop_5.10.0.871.orig.tar.bz2: monodevelop-5.10/src/core/MonoDevelop.Ide/MonoDevelop.Ide.Gui/ToolbarComboBox.cs <==
//
// ConfigurationComboBox.cs
//
// Author:
//   Lluis Sanchez Gual
//
// Copyright (C) 2005 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

using System;
using MonoDevelop.Core;
using MonoDevelop.Projects;
using MonoDevelop.Components.Commands;

namespace MonoDevelop.Ide.Gui
{
	public class ToolbarComboBox: CustomItem
	{
		Gtk.Alignment align;
		Gtk.ComboBox combo;
		Gtk.CellRendererText ctx;
		
		public ToolbarComboBox () 
		{
			align = new Gtk.Alignment (0.5f, 0.5f, 1.0f, 0f);
			Add (align);
			
			align.LeftPadding = 3;
			align.RightPadding = 3;
			
			combo = new Gtk.ComboBox ();
			combo.Model = new Gtk.ListStore (typeof(string));
			ctx = new Gtk.CellRendererText ();
			combo.PackStart (ctx, true);
			combo.AddAttribute (ctx, "text", 0);
			
			align.Add (combo);
			ShowAll ();
		}
		
		protected Gtk.ComboBox Combo {
			get { return combo; }
		}
		
		public override void SetToolbarStyle (Gtk.Toolbar toolbar)
		{
			if (Style != null) {
				if (toolbar.IconSize == Gtk.IconSize.Menu || toolbar.IconSize == Gtk.IconSize.SmallToolbar) {
					Pango.FontDescription fd = Style.FontDescription.Copy ();
					fd.Size = (int) (fd.Size * Pango.Scale.Small);
					ctx.FontDesc = fd;
				} else {
					ctx.FontDesc = Style.FontDescription;
				}
			}
		}
	}
}
